﻿namespace ULtraChartPieChart
{
    using System;
    using System.Data;
    using System.Windows.Forms;
    using Infragistics.Win.UltraWinChart;

    public partial class Form1 : Form
    {
        #region Constructor
        public Form1()
        {
            this.InitializeComponent();
            this.Load += Form1_Load;
            this.ultraChart1.ChartDataClicked += UltraChart1_ChartDataClicked;
            this.trackBarX.Scroll += TrackBar_Scroll;
            this.trackBarY.Scroll += TrackBar_Scroll;
            this.trackBarZ.Scroll += TrackBar_Scroll;
        }
        #endregion // Constructor

        #region UltraChart1_ChartDataClicked
        private void UltraChart1_ChartDataClicked(object sender, Infragistics.UltraChart.Shared.Events.ChartDataEventArgs e)
        {
            // Get the chart
            var chart = sender as UltraChart;
            if(chart == null)
                return;

            //  Get the data row related to the clicked slice
            var rowIndex = e.DataRow;

            //  If the slice is already broken its index will be in ExplicitlyBrokenSlices
            //  collection. If so we do not want to break it but to places it back
            var shouldBreakSlice = !chart.PieChart3D.GetOnlyExplicitlyBrokenSlices().Contains(rowIndex);

            //  Break or places back the clicked slice
            chart.PieChart3D.BreakSlice(rowIndex, shouldBreakSlice);
        }
        #endregion // UltraChart1_ChartDataClicked

        #region Form1_Load
        private void Form1_Load(object sender, EventArgs e)
        {
            //  Setup the chart and add some data
            this.ultraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.PieChart3D;
            this.ultraChart1.DataSource = this.GetData();

            //  Set the track bars
            this.trackBarX.Value = 40;
            this.trackBarY.Value = 40;
            this.trackBarZ.Value = 180;

            //  Set some nice initial rotation to the chart
            this.ultraChart1.Transform3D.XRotation = 40;
            this.ultraChart1.Transform3D.YRotation = 40;
            this.ultraChart1.Transform3D.ZRotation = 180;

            //  Set the lables
            this.labelX.Text = "X Rotation " + this.ultraChart1.Transform3D.XRotation;
            this.labelY.Text = "Y Rotation " + this.ultraChart1.Transform3D.YRotation;
            this.labelZ.Text = "Z Rotation " + this.ultraChart1.Transform3D.ZRotation;
        }
        #endregion // Form1_Load

        #region TrackBar_Scroll
        private void TrackBar_Scroll(object sender, EventArgs e)
        {
            //  This handler gets the track bar value and rotates the corresponding
            //  chart axis. It is also shows current value in the labels above
            var tb = sender as TrackBar;
            if(tb == null)
                return;

            var value = tb.Value;

            switch(tb.Name)
            {
                case "trackBarX":
                    this.ultraChart1.Transform3D.XRotation = value;
                    this.labelX.Text = "X Rotation " + value;
                    break;
                case "trackBarY":
                    this.ultraChart1.Transform3D.YRotation = value;
                    this.labelY.Text = "Y Rotation " + value;
                    break;
                case "trackBarZ":
                    this.ultraChart1.Transform3D.ZRotation = value;
                    this.labelZ.Text = "Z Rotation " + value;
                    break;
            }
        }
        #endregion // TrackBar_Scroll

        #region GetData
        private DataTable GetData()
        {
            //  Create some dummy data for the chart
            var data = new DataTable();

            data.Columns.Add("Product", typeof(string));
            data.Columns.Add("Units Sold", typeof(int));

            data.Rows.Add("Java", 225);
            data.Rows.Add("AciveX", 653);
            data.Rows.Add(".Net1", 335);
            data.Rows.Add("Misc", 132);
            data.Rows.Add("Native", 56);
            data.Rows.Add(".Net2", 62);
            data.Rows.Add("Apple", 42);

            return data;
        }
        #endregion // GetData
    }
}
